@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::KENTNL::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '2.001000';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '2.002000';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -170,20 +170,20 @@ sub bundle_config_inner {
   my (@sharedir) = ();
 
   my (@gatherfiles) = (
-    [ 'Git::GatherDir'       => { include_dotfiles    => 1 } ],
-    [ 'License'              => {} ],
-    [ 'MetaJSON'             => {} ],
-    [ 'MetaYAML'             => {} ],
-    [ 'Manifest'             => {} ],
-    [ 'MetaTests'            => {} ],
-    [ 'PodCoverageTests'     => {} ],
-    [ 'PodSyntaxTests'       => {} ],
-    [ 'ReportVersions::Tiny' => {} ],
-    [ 'Test::Kwalitee'       => {} ],
-    [ 'EOLTests'             => { trailing_whitespace => 1, } ],
-    [ 'Test::MinimumVersion' => {} ],
-    [ 'Test::Compile'        => {} ],
-    [ 'Test::Perl::Critic'   => {} ],
+    [ 'Git::GatherDir'         => { include_dotfiles    => 1 } ],
+    [ 'License'                => {} ],
+    [ 'MetaJSON'               => {} ],
+    [ 'MetaYAML'               => {} ],
+    [ 'Manifest'               => {} ],
+    [ 'MetaTests'              => {} ],
+    [ 'PodCoverageTests'       => {} ],
+    [ 'PodSyntaxTests'         => {} ],
+    [ 'ReportVersions::Tiny'   => {} ],
+    [ 'Test::Kwalitee'         => {} ],
+    [ 'EOLTests'               => { trailing_whitespace => 1, } ],
+    [ 'Test::MinimumVersion'   => {} ],
+    [ 'Test::Compile::PerFile' => {} ],
+    [ 'Test::Perl::Critic'     => {} ],
   );
 
   my (@prunefiles) = ( [ 'PruneCruft' => { except => '^.(perltidyrc|travis.yml|proverc)' } ], [ 'ManifestSkip' => {} ], );
@@ -279,7 +279,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.001000
+version 2.002000
 
 =head1 SYNOPSIS
 
